package eg.marathon;

import javax.swing.*;
import javax.swing.table.DefaultTableModel;
import javax.swing.tree.DefaultMutableTreeNode;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

public class SampleApp {
	private JDialog _dialog;

	public void show() {
		_dialog = new JDialog();
		_dialog.setTitle("Sample Dialog");
		_dialog.setBounds(300, 200, 200, 150);
		_dialog.getContentPane().setLayout(new FlowLayout());

		JMenuBar bar = new JMenuBar();
		JMenu fileMenu = new JMenu("File");
		fileMenu.add("Save");
		bar.add(fileMenu);
		JMenu toolMenu = new JMenu("Tool");
		toolMenu.add("Search");
		bar.add(toolMenu);
		_dialog.setJMenuBar(bar);

		JTabbedPane pane = new JTabbedPane();
		pane.addTab("Simple Widgets", createSimpleWidgetPanel());
		pane.addTab("Table", createTablePanel());
		pane.addTab("Tree", createTreePanel());

		_dialog.getContentPane().add(pane);

		_dialog.addWindowListener(new WindowAdapter() {
			public void windowClosing(WindowEvent e) {
				System.exit(0);
			}
		});

		_dialog.pack();
		_dialog.show();
	}

	private JPanel createTreePanel() {
		JPanel panel = new JPanel();

		DefaultMutableTreeNode rootNode = new DefaultMutableTreeNode("root");
		DefaultMutableTreeNode level1child1 = new DefaultMutableTreeNode("level1 - 1");
		rootNode.add(level1child1);
		DefaultMutableTreeNode level1child2 = new DefaultMutableTreeNode("level1 - 2");
		rootNode.add(level1child2);
		DefaultMutableTreeNode level2child1 = new DefaultMutableTreeNode("level2 - 1");
		level1child2.add(level2child1);

		JTree tree = new JTree(rootNode);
		panel.add(new JScrollPane(tree));

		return panel;
	}

	private JPanel createTablePanel() {
		JPanel panel = new JPanel();

		JTable table = new JTable(new String[][]{
			{"A", "B", "C"},
			{"D", "E", "F"},
			{"G", "H", "I"}
		}, new String[]{"Column1", "Column2", "Column3"});
		table.setName("sample table");
		panel.add(table);

		JTable table2 = new JTable();
		table2.setName("sample non-editable table");
		table2.setModel(new DefaultTableModel(
				new String[][]{
					{"0,0", "1,0", "2,0"},
					{"0,1", "1,1", "1,2"},
					{"0,2", "1,2", "2,2"}
				}, new String[]{"Column1", "Column2", "Column3"}
		) {
			public boolean isCellEditable(int row, int column) {
				return false;
			}
		});
		panel.add(table2);

		return panel;
	}

	private JPanel createSimpleWidgetPanel() {
		JPanel panel = new JPanel();

		JButton button = new JButton("Press Me");
		panel.add(button);

		JTextField textField = new JTextField("some text");
		textField.setName("textField");
		panel.add(textField);

		JComboBox comboBox = new JComboBox(new String[]{"foo", "bar", "baz"});
		comboBox.setName("comboBox");
		panel.add(comboBox);

		JButton messageBoxButton = new JButton("Show Message Dialog");
		panel.add(messageBoxButton);
		messageBoxButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				JOptionPane.showMessageDialog(_dialog, "Message Dialog", "Message Dialog",
						JOptionPane.INFORMATION_MESSAGE);
			}
		});

		JList list = new JList(new String[]{"item0", "item1", "item2", "item3"});
        panel.add(list);

		return panel;
	}

	public void close() {
		_dialog.dispose();
	}

	public static void main(String[] args) {
		SampleApp sampleApp = new SampleApp();
		sampleApp.show();
	}
}

